@@ -1,8 +1,5 @@
 def gitignore_content() -> str:
     return """
-# packages
-/packages
-
 # python
 __pycache__
 
